####################################################################################################
#
# Anatomical Network Analysis of Pectoral and Pelvic Appendages
#
# Supplementary materials for article in Evolution ID 0385 R1
# This script was used to analyze the network models of pectoral and pelvic appendages of 6 taxa and compare them.
# The first block analyzes the skeletal component (nodes = bones/cartilages; links = articulation).
# The second block analyzes the muscular component (nodes = muscles; links = common sites of attachment).
#
# Created on 22 November 2017
# By Borja Esteve-Altava
#
# R version 3.4.0 (2017-04-21) -- "You Stupid Darkness"
# Platform: x86_64-pc-linux-gnu (64-bit)
####################################################################################################

# 1. PREAMBLE
# 1.1. Packages
library(XLConnect)    # load adjacency matrices to R from .xls data file
library(igraph)       # perform network analyses
library(ape)          # perform phylogenetic analyses
library(phytools)     # perform phylogenetic analyses

# 1.2. Variables
species <- c("Polypterus PECA", "Polypterus PELA", "Latimeria PECA", "Latimeria PELA", "Neoceratodus PECA", "Neoceratodus PELA", "Ambystoma PECA", "Ambystoma PELA", "Salamandra PECA", "Salamandra PELA", "Sphenodon PECA", "Sphenodon PELA")
par_names <- c("N", "K", "D", "C", "L", "H", "P")
last_bone <- c(47, 9, 24, 23, 55, 64, 25, 32, 25, 32, 37, 31) # position of the last skeletal element
ite <- 1000 # iterations of the modularity analysis
simulite <- 10000 # sample size of noisy networks
# 1.3. Musculoskeletal networks
mat.list <- mapply(readWorksheetFromFile, "SI Dataset. Adjacency matrices 2Nov17.xls", sheet = 1:length(species), rownames = 1)
adj.list <- lapply(mat.list, data.matrix, rownames.force = TRUE)
complete.graph.list <- lapply(adj.list, graph_from_adjacency_matrix, mode = "undirected")
names(complete.graph.list) <- species

# 1.3. External functions
# 1.3.1. Wilcox test to evaluate modules
community.significance.test <- function(graph, vids, ...) {
  subgraph <- induced_subgraph(graph, vids)
  in.degrees <- degree(subgraph)
  out.degrees <- degree(graph, vids) - in.degrees
  wilcox.test(in.degrees, out.degrees, alternative = "greater")
}
# 1.3.2. Jackknife of modularity Q value
jackknife_Q = function(graph, membership){
  Qi <- vector()
  for (j in 1:ecount(graph)){
    g <- delete_edges(graph, j)
    Qi[j] <- modularity(g, membership)
  }
  ss <- sum((Qi-mean(Qi))^2)
  n <- (ecount(graph)-1)/ecount(graph)
  Q.error <- sqrt(n*ss)
  return(Q.error)
}
# 1.3.3. Compute the heterogeneity of connections (H)
heterogeneity = function(graph){
  deg = degree(graph)
  res = sd(deg, na.rm = TRUE)/mean(deg, na.rm = FALSE)
}
# 1.3.4. Compute the parcellation index (P)
parcellation_index <- function(membership){
  Nm <- vector()
  for (i in 1:max(membership)){
    Nm[i] <- length(which(membership==i))
  }
  res <- 1-sum((Nm/length(membership))^2)
  return(res)
}
# 1.3.5. Compute relative differences (dr)
Rdiff <- function(x, y){
  res = abs(x-y) / (abs(x+y)/2)
  return(res)
}
# 1.3.6. Clean 5% outliers in distribution (take 95% of the distribution)
remove_outliers <- function(x, na.rm = TRUE, ...) {
  qnt <- quantile(x, probs=c(.025, .975), na.rm = na.rm, ...)
  H <- 1.5 * IQR(x, na.rm = na.rm)
  y <- x
  y[x < (qnt[1] - H)] <- NA
  y[x > (qnt[2] + H)] <- NA
  y
}


# 2. SAMPLING NOISY NETWORKS TO TEST ROBUSTLESS (used later)
# 2.1. Create 10000 noisy networks with 5% error from the musculoskeletal matrices
set.seed(73)
noisy_networks_skeletal <-noisy_networks_muscular <- list()
for (i in 1:length(species)){ # for each network
  g <- complete.graph.list[[i]]
  noisy_gs <- noisy_gm <- list()
  for (j in 1:simulite){
    # multiple links and loops are allowed in the rewiring, but are then removed by simplifying the network
    # this allows to produce variation of links (variation in K and D)
    ng <- simplify(rewire(g, each_edge(p = .05, loops = T, multiple = T))) # 5% variation
    # get the skeletal component
    ngs <- induced_subgraph(ng, vids = 1:last_bone[i])
    cl <- components(ngs) # to make sure we take the largest connected component of the network (this allows variation in N)
    noisy_gs[[j]] <- induced_subgraph(ngs, vids = which(cl$membership == which.max(cl$csize)))
    # get the muscular component
    adj <- as.matrix(as_adjacency_matrix(ng, type = "both")) # the following lines help make the bipartite projection
    adj[1:last_bone[i], 1:last_bone[i]] <- NA
    adj[(last_bone[i]+1):dim(adj)[1], (last_bone[i]+1):dim(adj)[1]] <- NA
    ng <- graph_from_adjacency_matrix(adj, mode = "undirected")
    bipart <- rep(TRUE, times = vcount(ng))
    bipart[1:last_bone[i]] <- FALSE
    V(ng)$type <- bipart
    ngm <- bipartite_projection(ng, which = "true")
    cl <- components(ngm) # to make sure we take the largest connected component of the network (this allows variation in N)
    noisy_gm[[j]] <- induced_subgraph(ngm, vids = which(cl$membership == which.max(cl$csize)))
  }
  noisy_networks_skeletal[[i]] <- noisy_gs
  noisy_networks_muscular[[i]] <- noisy_gm
}


# 3. ANALYSIS OF SKELETAL NETWORKS
# 3.1. Create igraph networks for the skeletal component
graph.list <- list()
for (i in 1:length(species)){ # discart disconnected elements, if any
  graph.list[[i]] <- induced_subgraph(complete.graph.list[[i]], vids = 1:last_bone[i])
  cl <- components(graph.list[[i]]) # to make sure we take the largest connected component of the network
  graph.list[[i]] <- induced_subgraph(graph.list[[i]], vids = which(cl$membership == which.max(cl$csize)))
}
names(graph.list) <- species # name networks
graph.list_skeletal <- graph.list 

# 3.2. Modularity analysis (we need it for later, to calculate P)
# 3.2.1. Community detection algorithm
communities <- list()
for (i in 1:length(species)){
  saveSpin <- list()
  saveQ <- vector()
  set.seed(73)
  for (n in 1:ite){
    saveSpin[[n]] <- cluster_spinglass(graph.list[[i]])
    saveQ[n] <- modularity(saveSpin[[n]])
  }
  #consensusQ <- as.numeric(names(which.max(table(saveQ)))) # use this is for consensus partition
  #index <- which(saveQ==consensusQ)[1]                     # use this is for consensus partition
  index <- which.max(saveQ)                                 # use this is for optimal partition
  communities[[i]] <- saveSpin[[index]]                     # use this is for optimal partition
}
communities_skeletal <- communities

# 3.2.2. Save modularity results
modules <- matrix(NA, nrow = length(species), ncol = 3)
rownames(modules) <- species
colnames(modules) <- c("Modules (M)", "Q value", "Q expected error")
for (i in 1:length(species)){
  modules[i,1] <- length(communities[[i]])  # number of modules found
  modules[i,2] <- modularity(communities[[i]])  # value of the optimization parameter Q
  modules[i,3] <- jackknife_Q(graph.list[[i]], membership(communities[[i]]))  # expected error of the value Q
}
modules_skeletal <- modules
write.csv(modules_skeletal, file = "Supplementary Table 16. Summary of the modularity analysis in skeletal networks.xls") # save it externally

# 3.2.3. Save modularity details for each network
list.modules <- list()
for (i in 1:length(species)){
  graph <- graph.list[[i]]
  community <- communities[[i]]
  mod.tab <- matrix(NA, nrow = length(community), ncol = 3)
  colnames(mod.tab) <- c("ID", "p-value", "Node members")
  for (j in 1:length(community)){
    mod.tab[j,1] <- paste(j) # id of the module, only orientative, no meaning
    mod.tab[j,2] <- round(community.significance.test(graph, vids = (membership(community)==j))$p.value, digits = 5)  # p-value of the module
    mod.tab[j,3] <- paste(V(graph)$name[membership(community)==j], collapse = ", ") # nodes grouped within a module
  }
  list.modules[[i]] <- mod.tab
}
names(list.modules) <- species
list.modules_skeletal <- list.modules
for (i in 1:length(species)){ # save it externally
  write.csv(list.modules_skeletal[[i]][,-1], file = paste("Supplementary Table ", 16+i, ". Connectivity modules for the skeleton of ", species[i],".xls", sep = ""))
}

# 3.3. Parameters calculation
parameters <- matrix(NA, nrow = length(species), ncol = 7)
rownames(parameters) <- species
colnames(parameters) <- par_names
parameters[,1] <- mapply(vcount, graph.list)
parameters[,2] <- mapply(ecount, graph.list)
parameters[,3] <- mapply(edge_density, graph.list)
parameters[,4] <- mapply(transitivity, graph.list, type = "average", isolates = "NaN")
parameters[,5] <- mapply(mean_distance, graph.list, directed = FALSE)
parameters[,6] <- mapply(heterogeneity, graph.list)
for (i in 1:length(species)){
  parameters[i,7] <- parcellation_index(membership(communities[[i]]))
}
parameters_skeletal <- parameters
write.csv(parameters_skeletal, file = "Table 1. Network parameters skeletal networks.xls") # save it externally

# 3.3.1. Calculate parameters for noisy skeletal networks (to test robustness)
mean_parameters <- sd_parameters <- parameters # mean and sd of the noisy sample
noisy_parameters <- rep(list(list()), length(species)) 
for (i in 1:length(species)){
  noisy_parameters[[i]][[1]] <- unlist(mapply(vcount, noisy_networks_skeletal[[i]])) # N
  noisy_parameters[[i]][[1]] <- remove_outliers(noisy_parameters[[i]][[1]])
  mean_parameters[i,1] <- mean(noisy_parameters[[i]][[1]], na.rm = TRUE)
  sd_parameters[i,1] <- sd(noisy_parameters[[i]][[1]], na.rm = TRUE)
  noisy_parameters[[i]][[2]] <- unlist(mapply(ecount, noisy_networks_skeletal[[i]])) # K
  noisy_parameters[[i]][[2]] <- remove_outliers(noisy_parameters[[i]][[2]])
  mean_parameters[i,2] <- mean(noisy_parameters[[i]][[2]], na.rm = TRUE)
  sd_parameters[i,2] <- sd(noisy_parameters[[i]][[2]], na.rm = TRUE)
  noisy_parameters[[i]][[3]] <- unlist(mapply(edge_density, noisy_networks_skeletal[[i]])) # D
  noisy_parameters[[i]][[3]] <- remove_outliers(noisy_parameters[[i]][[3]])
  mean_parameters[i,3] <- mean(noisy_parameters[[i]][[3]], na.rm = TRUE)
  sd_parameters[i,3] <- sd(noisy_parameters[[i]][[3]], na.rm = TRUE)
  noisy_parameters[[i]][[4]] <- unlist(mapply(transitivity, noisy_networks_skeletal[[i]], type = "average", isolates = "NaN")) # C
  noisy_parameters[[i]][[4]] <- remove_outliers(noisy_parameters[[i]][[4]])
  mean_parameters[i,4] <- mean(noisy_parameters[[i]][[4]], na.rm = TRUE)
  sd_parameters[i,4] <- sd(noisy_parameters[[i]][[4]], na.rm = TRUE)
  noisy_parameters[[i]][[5]] <- unlist(mapply(mean_distance, noisy_networks_skeletal[[i]], directed = FALSE)) # L
  noisy_parameters[[i]][[5]] <- remove_outliers(noisy_parameters[[i]][[5]])
  mean_parameters[i,5] <- mean(noisy_parameters[[i]][[5]], na.rm = TRUE)
  sd_parameters[i,5] <- sd(noisy_parameters[[i]][[5]], na.rm = TRUE)
  noisy_parameters[[i]][[6]] <- unlist(mapply(heterogeneity, noisy_networks_skeletal[[i]])) # H
  noisy_parameters[[i]][[6]] <- remove_outliers(noisy_parameters[[i]][[6]])
  mean_parameters[i,6] <- mean(noisy_parameters[[i]][[6]], na.rm = TRUE)
  sd_parameters[i,6] <- sd(noisy_parameters[[i]][[6]], na.rm = TRUE)
  n_parcellation <- n_parcellation_clean <- vector() # P
  set.seed(73)
  for (j in 1:length(noisy_networks_skeletal[[i]])){
    n_membership <- cluster_spinglass(noisy_networks_skeletal[[i]][[j]])$membership # for P we calculate one partition for each noisy network
    n_parcellation[j] <- parcellation_index(n_membership)
  }
  noisy_parameters[[i]][[7]] <- n_parcellation
  mean_parameters[i,7] <- mean(noisy_parameters[[i]][[7]], na.rm = TRUE)
  sd_parameters[i,7] <- sd(noisy_parameters[[i]][[7]], na.rm = TRUE)
}
noisy_parameters_skeletal <- noisy_parameters
mean_noisy_parameters_skeletal <- mean_parameters
sd_noisy_parameters_skeletal <- sd_parameters
sem_noisy_parameters_skeletal <- sd_noisy_parameters_skeletal / sqrt(length(noisy_networks_skeletal[[1]])) # standard error of the mean
write.csv(mean_noisy_parameters_skeletal, file = "Supplementary Table 7. Mean values of parameters in 10000 noisy skeletal networks.xls") # save externally
write.csv(sd_noisy_parameters_skeletal, file = "Supplementary Table 8. SD values of parameters in 10000 noisy skeletal networks.xls")
write.csv(sem_noisy_parameters_skeletal, file = "Supplementary Table 9. SEM values of parameters in 10000 noisy skeletal networks.xls")

# 3.3.2. Is observation within the range of the sample of noisy networks?
# H0: Observation = mean of the sample
# Ha: Observation ≠ mean of the sample
# alpha (p-value) 0.05
lower_Q <- matrix(FALSE, nrow = length(species), ncol = 7)
rownames(lower_Q) <- species
colnames(lower_Q) <- par_names
upper_Q <- lower_Q
within_IQR <- lower_Q
for (i in 1:length(species)){
  for (j in 1:7){
    lower_Q[i,j] <- quantile(noisy_parameters_skeletal[[i]][[j]], probs = c(0, 0.025, 0.5, 0.975, 1), type = 8, names = FALSE, na.rm = TRUE)[2]
    upper_Q[i,j] <-quantile(noisy_parameters_skeletal[[i]][[j]], probs = c(0, 0.025, 0.5, 0.975, 1), type = 8, names = FALSE, na.rm = TRUE)[4]
    if (parameters_skeletal[i,j] >= lower_Q[i,j] & parameters_skeletal[i,j] <= upper_Q[i,j]){
      within_IQR[i,j] <- TRUE
    }
  }
}
m <- cbind(lower_Q, upper_Q) # combine
Q95_skeletal <- m[, c(matrix(1:ncol(m), nrow = 2, byrow = T))] # then reorder
colnames(Q95_skeletal) <- c("Lower N", "Upper N", "Lower K", "Upper K", "Lower D", "Upper D", "Lower C", "Upper C", "Lower L", "Upper L", "Lower H", "Upper H", "Lower P", "Upper P")
within_IQR_skeletal <- within_IQR

# 3.3.2.1. Values of TRUE mean that we cannot reject H0. Thus, the observed value falls within the range of the average noisy networks.
write.csv(Q95_skeletal, file = "Supplementary Table 10. Inter 95% distribution range values of parameters in 10000 noisy skeletal networks.xls")
write.csv(within_IQR_skeletal, file = "Supplementary Table 11. Test of observed values in skeletal network falling within the 95% range of 10000 noisy skeletal networks.xls")

# 3.4. Measuring the relative difference between a pair of networks
# 3.4.1. Relative difference of PECAs
parameters_PEC <- parameters[seq(1, 12, 2),]
Rdiff_spPEC <- matrix(NA, nrow = 15, ncol = 7)
rownames(Rdiff_spPEC) <- c("Polypterus vs. Latimeria", "Polypterus vs. Neoceratodus", "Polypterus vs. Ambystoma", "Polypterus vs. Salamandra", "Polypterus vs. Sphenodon", "Latimeria vs. Neoceratodus", "Latimeria vs. Ambystoma", "Latimeria vs. Salamandra", "Latimeria vs. Sphenodon", "Neoceratodus vs. Ambystoma", "Neoceratodus vs. Salamandra", "Neoceratodus vs. Sphenodon", "Ambystoma vs. Salamandra", "Ambystoma vs. Sphenodon", "Salamandra vs. Sphenodon")
colnames(Rdiff_spPEC) <- colnames(parameters)
Rdiff_spPEC[1,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[2,])
Rdiff_spPEC[2,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[3,])
Rdiff_spPEC[3,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[4,])
Rdiff_spPEC[4,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[5,])
Rdiff_spPEC[5,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[6,])
Rdiff_spPEC[6,] <- mapply(Rdiff, parameters_PEC[2,], parameters_PEC[3,])
Rdiff_spPEC[7,] <- mapply(Rdiff, parameters_PEC[2,], parameters_PEC[4,])
Rdiff_spPEC[8,] <- mapply(Rdiff, parameters_PEC[2,], parameters_PEC[5,])
Rdiff_spPEC[9,] <- mapply(Rdiff, parameters_PEC[2,], parameters_PEC[6,])
Rdiff_spPEC[10,] <- mapply(Rdiff, parameters_PEC[3,], parameters_PEC[4,])
Rdiff_spPEC[11,] <- mapply(Rdiff, parameters_PEC[3,], parameters_PEC[5,])
Rdiff_spPEC[12,] <- mapply(Rdiff, parameters_PEC[3,], parameters_PEC[6,])
Rdiff_spPEC[13,] <- mapply(Rdiff, parameters_PEC[4,], parameters_PEC[5,])
Rdiff_spPEC[14,] <- mapply(Rdiff, parameters_PEC[4,], parameters_PEC[6,])
Rdiff_spPEC[15,] <- mapply(Rdiff, parameters_PEC[5,], parameters_PEC[6,])
Rdiff_spPEC_skeletal <- Rdiff_spPEC
write.csv(round(Rdiff_spPEC_skeletal*100, digits=1), file = "Supplementary Table 1. Percentage of relative difference of parameters among pectoral skeletal networks.xls")

# 3.4.2. Relative difference of PELAs
parameters_PEL <- parameters[seq(2, 12, 2),]
Rdiff_spPEL <- matrix(NA, nrow = 15, ncol = 7)
rownames(Rdiff_spPEL) <- rownames(Rdiff_spPEC)
colnames(Rdiff_spPEL) <- colnames(parameters)
Rdiff_spPEL[1,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[2,])
Rdiff_spPEL[2,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[3,])
Rdiff_spPEL[3,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[4,])
Rdiff_spPEL[4,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[5,])
Rdiff_spPEL[5,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[6,])
Rdiff_spPEL[6,] <- mapply(Rdiff, parameters_PEL[2,], parameters_PEL[3,])
Rdiff_spPEL[7,] <- mapply(Rdiff, parameters_PEL[2,], parameters_PEL[4,])
Rdiff_spPEL[8,] <- mapply(Rdiff, parameters_PEL[2,], parameters_PEL[5,])
Rdiff_spPEL[9,] <- mapply(Rdiff, parameters_PEL[2,], parameters_PEL[6,])
Rdiff_spPEL[10,] <- mapply(Rdiff, parameters_PEL[3,], parameters_PEL[4,])
Rdiff_spPEL[11,] <- mapply(Rdiff, parameters_PEL[3,], parameters_PEL[5,])
Rdiff_spPEL[12,] <- mapply(Rdiff, parameters_PEL[3,], parameters_PEL[6,])
Rdiff_spPEL[13,] <- mapply(Rdiff, parameters_PEL[4,], parameters_PEL[5,])
Rdiff_spPEL[14,] <- mapply(Rdiff, parameters_PEL[4,], parameters_PEL[6,])
Rdiff_spPEL[15,] <- mapply(Rdiff, parameters_PEL[5,], parameters_PEL[6,])
Rdiff_spPEL_skeletal <- Rdiff_spPEL
write.csv(round(Rdiff_spPEL_skeletal*100, digits=1), file = "Supplementary Table 2. Percentage of relative differences of parameters among pelvic skeletal networks.xls")

# 3.4.3. Relative difference PECA vs. PELA
Rdiff_PECvsPEL <- matrix(NA, nrow = 6, ncol = 7)
rownames(Rdiff_PECvsPEL) <- c("Polypterus", "Latimeria", "Neoceratodus", "Ambystoma", "Salamandra", "Sphenodon")
colnames(Rdiff_PECvsPEL) <- colnames(parameters)
for (i in 1:6){
  Rdiff_PECvsPEL[i,] <- mapply(Rdiff, parameters_PEC[i,], parameters_PEL[i,])
}
Rdiff_PECvsPEL_skeletal <- Rdiff_PECvsPEL
write.csv(round(Rdiff_PECvsPEL_skeletal*100, digits=1), file = "Supplementary Table 3. Percentage of relative difference between pectoral and pelvic skeletal networks.xls")

# 3.4.3.1. Plot PEC-PEL differences
svg(filename=paste("Supplementary Figure 1. Relative differences between pectoral and pelvic skeletons.svg"), width=7, height=5)
dat <- Rdiff_PECvsPEL_skeletal[,-8:-9]*100
matplot(dat, type = c("b"), pch = 1, col = 1:7, xaxt = "n", yaxt = "n", ylab = "PECA vs. PELA Relative Difference (%)") #plot
legend("topright", legend = par_names, col=1:7, pch=1) # optional legend
axis(1, at = 1:6, labels = rownames(dat), cex.axis = 0.9)
axis(2, cex.axis=0.9, las = 1)
dev.off()

# 3.5. Ancestral state reconstructions
# 3.5.1. Load and set tree
tree <- read.tree(file = "fin_limb_tree.txt")
plotname <- c("Number of nodes (N)", "Number of connections (K)", "Density of connections (D)", "Clustering coefficient (C)", "Shortest path length (L)", "Heterogeneity (H)", "Parcellation (P)")
genera <- c("Polypterus", "Latimeria", "Neoceratodus", "Ambystoma", "Salamandra", "Sphenodon")

# 3.5.2. Create phylomorphospaces
svg(filename="Figure 4. Phylomorphospace skeletal networks.svg", width=8.27, height=11.69)
par(mfrow = c(4,2))
for (i in 1:7){
  trait1 <- as.vector(parameters_PEC[,i])
  trait2 <- as.vector(parameters_PEL[,i])
  X <- cbind(trait1, trait2)
  rownames(X) <- genera
  range <- as.numeric(c(trait1,trait2))
  tip.cols <- c("blue","cyan","cyan", "dark green", "dark green", "dark green")
  names(tip.cols)<-tree$tip.label
  cols<-c(tip.cols[tree$tip.label],rep("black",tree$Nnode))
  names(cols)<-1:(length(tree$tip)+tree$Nnode)
  par(pty="s")
  phylomorphospace(tree, X, label = "horizontal",
                   xlim = c(min(range),max(range)),
                   ylim = c(min(range),max(range)),
                   xlab = "Pectoral appendage",
                   ylab = "Pelvic appendage",
                   control=list(col.node=cols), lwd=2, ftype = "i")
  abline(a = 0, b = 1, col = "red", lty = "dashed", lwd=0.75)
}
dev.off()

# 3.5.3. Reconstruction values and 95%CI
rec_anc_PEC_skeletal <- matrix(0, nrow = 5, ncol = 7)
rownames(rec_anc_PEC_skeletal) <- c("Eutelostomi", "Sarcopterygii", "Riphidistia", "Tetrapoda", "Caudata")
colnames(rec_anc_PEC_skeletal) <- colnames(parameters)
rec_lower95CI_PEC_skeletal <- rec_upper95CI_PEC_skeletal <- rec_anc_PEC_skeletal
rec_anc_PEL_skeletal <- rec_lower95CI_PEL_skeletal <- rec_upper95CI_PEL_skeletal <- rec_anc_PEC_skeletal
for (i in 1:7){
  trait <- as.vector(parameters_PEC[,i]) # for pectoral appendages
  names(trait) <- genera
  rec <- fastAnc(tree,trait, CI = TRUE, vars = FALSE)
  rec_anc_PEC_skeletal[,i] <- round(as.numeric(rec$ace), digits = 3)
  rec_lower95CI_PEC_skeletal[,i] <-  round(as.numeric(rec$CI95[,1]), digits = 3)
  rec_upper95CI_PEC_skeletal[,i] <-  round(as.numeric(rec$CI95[,2]), digits = 3)
  trait <- as.vector(parameters_PEL[,i]) # for pelvic appendages
  names(trait) <- genera
  rec <- fastAnc(tree,trait, CI = TRUE, vars = FALSE)
  rec_anc_PEL_skeletal[,i] <- round(as.numeric(rec$ace), digits = 3)
  rec_lower95CI_PEL_skeletal[,i] <-  round(as.numeric(rec$CI95[,1]), digits = 3)
  rec_upper95CI_PEL_skeletal[,i] <-  round(as.numeric(rec$CI95[,2]), digits = 3)
}
m <- cbind(rec_anc_PEC_skeletal, rec_lower95CI_PEC_skeletal, rec_upper95CI_PEC_skeletal) # combine
ACE_PEC_skeletal <- m[, c(matrix(1:ncol(m), nrow = 3, byrow = T))] # then reorder
colnames(ACE_PEC_skeletal) <- c("ACE N","Lower 95%CI N", "Upper 95%CI N", "ACE K","Lower 95%CI K", "Upper 95%CI K", "ACE D","Lower 95%CI D", "Upper 95%CI D", "ACE C","Lower 95%CI C", "Upper 95%CI C", "ACE L","Lower 95%CI L", "Upper 95%CI L", "ACE H","Lower 95%CI H", "Upper 95%CI H", "ACE P","Lower 95%CI P", "Upper 95%CI P")
write.csv(ACE_PEC_skeletal, file = "Supplementary Table 12. Ancestral state reconstruction of pectoral skeletal network parameters (95% CIs).xls")
m <- cbind(rec_anc_PEL_skeletal, rec_lower95CI_PEL_skeletal, rec_upper95CI_PEL_skeletal) # combine
ACE_PEL_skeletal <- m[, c(matrix(1:ncol(m), nrow = 3, byrow = T))] # then reorder
colnames(ACE_PEL_skeletal) <- colnames(ACE_PEC_skeletal)
write.csv(ACE_PEL_skeletal, file = "Supplementary Table 13. Ancestral state reconstruction of pelvic skeletal network parameters (95% CIs).xls")

# 3.5.4. Moran's I test of autocorrelation
PECA_par <- data.frame(parameters_skeletal[seq(1, 12, 2),]) # check this!! maybe change
PELA_par <- data.frame(parameters_skeletal[seq(2, 12, 2),])
w <- 1/cophenetic(tree)
diag(w) <- 0
phyautocor_PECA <- phyautocor_PELA <- matrix(NA, nrow = 7, ncol = 3)
colnames(phyautocor_PECA) <- colnames(phyautocor_PELA) <- c("Moran's I", "Zi-score", "p-value")
rownames(phyautocor_PECA) <- rownames(phyautocor_PELA) <- par_names
set.seed(73)
for (i in 1:7){
  patest <- Moran.I(PECA_par[,i], w)
  phyautocor_PECA[i,] <- c(patest$observed, (patest$observed-patest$expected)/patest$sd, patest$p.value)
  patest <- Moran.I(PELA_par[,i], w)
  phyautocor_PELA[i,] <- c(patest$observed, (patest$observed-patest$expected)/patest$sd, patest$p.value)  
}
phyautocor_skeletal <- rbind(phyautocor_PECA, phyautocor_PELA) # combine
rownames(phyautocor_skeletal) <- c("N pectoral", "K pectoral", "D pectoral", "C pectoral", "L pectoral", "H pectoral", "P pectoral",
                                   "N pelvic", "K pelvic", "D pelvic", "C pelvic", "L pelvic", "H pelvic", "P pelvic")
write.csv(phyautocor_skeletal, file = "Supplementary Table 14. Moran's I test of autocorrelation on skeletal networks parameters.xls")

# 3.5.5. Regression through the origin of phylogenetic independent contrasts for pectoral-pelvic networks
regOrigin <- matrix(NA, ncol = 4, nrow = 7)
rownames(regOrigin) <- par_names
colnames(regOrigin) <- c("Adjusted r2", "Residual std error", "F-statistic", "p-value")
set.seed(73)
for (i in 1:7){
  reg0 <- lmorigin(pic(PECA_par[,i], tree) ~ pic(PELA_par[,i], tree), silent = T) # regression trought the origin (-1); coefficinet is the slope or how many times y is higher than x
  reg0sum <- summary(reg0$reg)
  regOrigin[i,1] <- reg0sum$adj.r.squared # r2
  regOrigin[i,2] <- reg0sum$sigma # error
  regOrigin[i,3] <- reg0sum$fstatistic[1] # F
  regOrigin[i,4] <- reg0$p.perm.F# pvalue
}
regOrigin_skeletal <- regOrigin
write.csv(regOrigin_skeletal, file = "Supplementary Table 15. Regression through the origin of phylogenetic independent contrasts for pectoral-pelvic skeletal networks.
.xls")

#
#
# 4. ANALYSIS OF MUSCULAR NETWORKS
# 4.1. Create igraph networks for the muscular component
graph.list <- list()
for (i in 1:length(species)){
  adj <- adj.list[[i]]
  adj[1:last_bone[i], 1:last_bone[i]] <- NA
  adj[(last_bone[i]+1):dim(adj)[1], (last_bone[i]+1):dim(adj)[1]] <- NA
  adj.list[[i]] <- adj
}
graph.list <- lapply(adj.list, graph_from_adjacency_matrix, mode = "undirected")
nodes_labels <- list()
nodes_labels_tag <- list()
for (i in 1:length(species)){
  bipart <- rep(TRUE, times = vcount(graph.list[[i]]))
  bipart[1:last_bone[i]] <- FALSE
  V(graph.list[[i]])$type <- bipart
  graph.list[[i]] <- bipartite_projection(graph.list[[i]], which = "true")
  cl <- components(graph.list[[i]]) # to make sure we take the largest connected component of the network
  graph.list[[i]] <- induced_subgraph(graph.list[[i]], vids = which(cl$membership == which.max(cl$csize)))
  nodes_labels[[i]] <- colnames(adj.list[[i]])[which(cl$membership == which.max(cl$csize)) + last_bone[i]] # this we use when we will plot networks, to have labels.
  nodes_labels_tag[[i]] <- which(cl$membership == which.max(cl$csize)) + last_bone[i]  # this we use when we will plot networks, to have labels.
}
names(graph.list) <- species
graph.list_muscular <- graph.list 

# 4.2. Modularity analysis (we need it for later, to calculate P)
# 4.2.1. Community detection algorithm
communities <- list()
for (i in 1:length(species)){
  saveSpin <- list()
  saveQ <- vector()
  set.seed(73)
  for (n in 1:ite){
    saveSpin[[n]] <- cluster_spinglass(graph.list[[i]])
    saveQ[n] <- modularity(saveSpin[[n]])
  }
  #consensusQ <- as.numeric(names(which.max(table(saveQ)))) # use this is for consensus partition
  #index <- which(saveQ==consensusQ)[1]                     # use this is for consensus partition
  index <- which.max(saveQ)                                 # use this is for optimal partition
  communities[[i]] <- saveSpin[[index]]                     # use this is for optimal partition
}
communities_muscular <- communities

# 4.2.2. Save modularity results
modules <- matrix(NA, nrow = length(species), ncol = 3)
rownames(modules) <- species
colnames(modules) <- c("Modules (M)", "Q value", "Q expected error")
for (i in 1:length(species)){
  modules[i,1] <- length(communities[[i]])  # number of modules found
  modules[i,2] <- modularity(communities[[i]])  # value of the optimization parameter Q
  modules[i,3] <- jackknife_Q(graph.list[[i]], membership(communities[[i]]))  # expected error of the value Q
}
modules_muscular <- modules
write.csv(modules_muscular, file = "Supplementary Table 38. Summary of the modularity analysis in muscular networks.xls") # save it externally

# 4.2.3. Save modularity details for each network
list.modules <- list()
for (i in 1:length(species)){
  graph <- graph.list[[i]]
  community <- communities[[i]]
  mod.tab <- matrix(NA, nrow = length(community), ncol = 3)
  colnames(mod.tab) <- c("ID", "p-value", "Node members")
  for (j in 1:length(community)){
    mod.tab[j,1] <- paste(j) # id of the module, only orientative, no meaning
    mod.tab[j,2] <- round(community.significance.test(graph, vids = (membership(community)==j))$p.value, digits = 5)  # p-value of the module
    mod.tab[j,3] <- paste(V(graph)$name[membership(community)==j], collapse = ", ") # nodes grouped within a module
  }
  list.modules[[i]] <- mod.tab
}
names(list.modules) <- species
list.modules_muscular <- list.modules
for (i in 1:length(species)){ # save it externally
  write.csv(list.modules_muscular[[i]][,-1], file = paste("Supplementary Table ", 38+i, ". Connectivity modules for the muscles of ", species[i],".xls", sep = ""))
}

# 4.3. Parameters calculation
parameters <- matrix(NA, nrow = length(species), ncol = 7)
rownames(parameters) <- species
colnames(parameters) <- par_names
parameters[,1] <- mapply(vcount, graph.list)
parameters[,2] <- mapply(ecount, graph.list)
parameters[,3] <- mapply(edge_density, graph.list)
parameters[,4] <- mapply(transitivity, graph.list, type = "average", isolates = "NaN")
parameters[,5] <- mapply(mean_distance, graph.list, directed = FALSE)
parameters[,6] <- mapply(heterogeneity, graph.list)
for (i in 1:length(species)){
  parameters[i,7] <- parcellation_index(membership(communities[[i]]))
}
parameters_muscular <- parameters
write.csv(parameters_muscular, file = "Table 2. Network parameters muscular networks.xls") # save it externally

# 4.3.1. Calculate parameters for noisy muscular networks (to test robustness)
mean_parameters <- sd_parameters <- parameters # mean and sd of the noisy sample
noisy_parameters <- rep(list(list()), length(species)) 
for (i in 1:length(species)){
  noisy_parameters[[i]][[1]] <- unlist(mapply(vcount, noisy_networks_muscular[[i]])) # N
  noisy_parameters[[i]][[1]] <- remove_outliers(noisy_parameters[[i]][[1]])
  mean_parameters[i,1] <- mean(noisy_parameters[[i]][[1]], na.rm = TRUE)
  sd_parameters[i,1] <- sd(noisy_parameters[[i]][[1]], na.rm = TRUE)
  noisy_parameters[[i]][[2]] <- unlist(mapply(ecount, noisy_networks_muscular[[i]])) # K
  noisy_parameters[[i]][[2]] <- remove_outliers(noisy_parameters[[i]][[2]])
  mean_parameters[i,2] <- mean(noisy_parameters[[i]][[2]], na.rm = TRUE)
  sd_parameters[i,2] <- sd(noisy_parameters[[i]][[2]], na.rm = TRUE)
  noisy_parameters[[i]][[3]] <- unlist(mapply(edge_density, noisy_networks_muscular[[i]])) # D
  noisy_parameters[[i]][[3]] <- remove_outliers(noisy_parameters[[i]][[3]])
  mean_parameters[i,3] <- mean(noisy_parameters[[i]][[3]], na.rm = TRUE)
  sd_parameters[i,3] <- sd(noisy_parameters[[i]][[3]], na.rm = TRUE)
  noisy_parameters[[i]][[4]] <- unlist(mapply(transitivity, noisy_networks_muscular[[i]], type = "average", isolates = "NaN")) # C
  noisy_parameters[[i]][[4]] <- remove_outliers(noisy_parameters[[i]][[4]])
  mean_parameters[i,4] <- mean(noisy_parameters[[i]][[4]], na.rm = TRUE)
  sd_parameters[i,4] <- sd(noisy_parameters[[i]][[4]], na.rm = TRUE)
  noisy_parameters[[i]][[5]] <- unlist(mapply(mean_distance, noisy_networks_muscular[[i]], directed = FALSE)) # L
  noisy_parameters[[i]][[5]] <- remove_outliers(noisy_parameters[[i]][[5]])
  mean_parameters[i,5] <- mean(noisy_parameters[[i]][[5]], na.rm = TRUE)
  sd_parameters[i,5] <- sd(noisy_parameters[[i]][[5]], na.rm = TRUE)
  noisy_parameters[[i]][[6]] <- unlist(mapply(heterogeneity, noisy_networks_muscular[[i]])) # H
  noisy_parameters[[i]][[6]] <- remove_outliers(noisy_parameters[[i]][[6]])
  mean_parameters[i,6] <- mean(noisy_parameters[[i]][[6]], na.rm = TRUE)
  sd_parameters[i,6] <- sd(noisy_parameters[[i]][[6]], na.rm = TRUE)
  n_parcellation <- n_parcellation_clean <- vector() # P
  set.seed(73)
  for (j in 1:length(noisy_networks_muscular[[i]])){
    if (vcount(noisy_networks_muscular[[i]][[j]])>1){
      n_membership <- cluster_spinglass(noisy_networks_muscular[[i]][[j]])$membership # for P we calculate one partition for each noisy network
      n_parcellation[j] <- parcellation_index(n_membership)
    } else {
      n_parcellation[j] <- 0
    }
  }
  noisy_parameters[[i]][[7]] <- n_parcellation
  mean_parameters[i,7] <- mean(noisy_parameters[[i]][[7]], na.rm = TRUE)
  sd_parameters[i,7] <- sd(noisy_parameters[[i]][[7]], na.rm = TRUE)
}
noisy_parameters_muscular <- noisy_parameters
mean_noisy_parameters_muscular <- mean_parameters
sd_noisy_parameters_muscular <- sd_parameters
sem_noisy_parameters_muscular <- sd_noisy_parameters_muscular / sqrt(length(noisy_networks_muscular[[1]])) # standard error of the mean
write.csv(mean_noisy_parameters_muscular, file = "Supplementary Table 29. Mean values of parameters in 10000 noisy muscular networks.xls") # save externally
write.csv(sd_noisy_parameters_muscular, file = "Supplementary Table 30. SD values of parameters in 10000 noisy muscular networks.xls")
write.csv(sem_noisy_parameters_muscular, file = "Supplementary Table 31. SEM values of parameters in 10000 noisy muscular networks.xls")

# 4.3.2. Is observation within the range of the sample of noisy networks?
# H0: Observation = mean of the sample
# Ha: Observation ≠ mean of the sample
# alpha (p-value) 0.05
lower_Q <- matrix(FALSE, nrow = length(species), ncol = 7)
rownames(lower_Q) <- species
colnames(lower_Q) <- par_names
upper_Q <- lower_Q
within_IQR <- lower_Q
for (i in 1:length(species)){
  for (j in 1:7){
    lower_Q[i,j] <- quantile(noisy_parameters_muscular[[i]][[j]], probs = c(0, 0.025, 0.5, 0.975, 1), type = 8, names = FALSE, na.rm = TRUE)[2]
    upper_Q[i,j] <-quantile(noisy_parameters_muscular[[i]][[j]], probs = c(0, 0.025, 0.5, 0.975, 1), type = 8, names = FALSE, na.rm = TRUE)[4]
    if (parameters_muscular[i,j] >= lower_Q[i,j] & parameters_muscular[i,j] <= upper_Q[i,j]){
      within_IQR[i,j] <- TRUE
    }
  }
}
m <- cbind(lower_Q, upper_Q) # combine
Q95_muscular <- m[, c(matrix(1:ncol(m), nrow = 2, byrow = T))] # then reorder
colnames(Q95_muscular) <- c("Lower N", "Upper N", "Lower K", "Upper K", "Lower D", "Upper D", "Lower C", "Upper C", "Lower L", "Upper L", "Lower H", "Upper H", "Lower P", "Upper P")
within_IQR_muscular <- within_IQR

# 4.3.2.1. Values of TRUE mean that we cannot reject H0. Thus, the observed value falls within the range of the average noisy networks.
write.csv(Q95_muscular, file = "Supplementary Table 32. Inter 95% distribution range values of parameters in 10000 noisy muscular networks.xls")
write.csv(within_IQR_muscular, file = "Supplementary Table 33. Test of observed values in muscular network falling within the 95% range of 10000 noisy muscular networks.xls")

# 4.4. Measuring the relative difference between a pair of networks
# 4.4.1. Relative difference of PECAs
parameters_PEC <- parameters[seq(1, 12, 2),]
Rdiff_spPEC <- matrix(NA, nrow = 15, ncol = 7)
rownames(Rdiff_spPEC) <- c("Polypterus vs. Latimeria", "Polypterus vs. Neoceratodus", "Polypterus vs. Ambystoma", "Polypterus vs. Salamandra", "Polypterus vs. Sphenodon", "Latimeria vs. Neoceratodus", "Latimeria vs. Ambystoma", "Latimeria vs. Salamandra", "Latimeria vs. Sphenodon", "Neoceratodus vs. Ambystoma", "Neoceratodus vs. Salamandra", "Neoceratodus vs. Sphenodon", "Ambystoma vs. Salamandra", "Ambystoma vs. Sphenodon", "Salamandra vs. Sphenodon")
colnames(Rdiff_spPEC) <- colnames(parameters)
Rdiff_spPEC[1,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[2,])
Rdiff_spPEC[2,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[3,])
Rdiff_spPEC[3,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[4,])
Rdiff_spPEC[4,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[5,])
Rdiff_spPEC[5,] <- mapply(Rdiff, parameters_PEC[1,], parameters_PEC[6,])
Rdiff_spPEC[6,] <- mapply(Rdiff, parameters_PEC[2,], parameters_PEC[3,])
Rdiff_spPEC[7,] <- mapply(Rdiff, parameters_PEC[2,], parameters_PEC[4,])
Rdiff_spPEC[8,] <- mapply(Rdiff, parameters_PEC[2,], parameters_PEC[5,])
Rdiff_spPEC[9,] <- mapply(Rdiff, parameters_PEC[2,], parameters_PEC[6,])
Rdiff_spPEC[10,] <- mapply(Rdiff, parameters_PEC[3,], parameters_PEC[4,])
Rdiff_spPEC[11,] <- mapply(Rdiff, parameters_PEC[3,], parameters_PEC[5,])
Rdiff_spPEC[12,] <- mapply(Rdiff, parameters_PEC[3,], parameters_PEC[6,])
Rdiff_spPEC[13,] <- mapply(Rdiff, parameters_PEC[4,], parameters_PEC[5,])
Rdiff_spPEC[14,] <- mapply(Rdiff, parameters_PEC[4,], parameters_PEC[6,])
Rdiff_spPEC[15,] <- mapply(Rdiff, parameters_PEC[5,], parameters_PEC[6,])
Rdiff_spPEC_muscular <- Rdiff_spPEC
write.csv(round(Rdiff_spPEC_muscular*100, digits=1), file = "Supplementary Table 4. Percentage of relative difference of parameters among pectoral muscular networks.xls")

# 4.4.2. Relative difference of PELAs
parameters_PEL <- parameters[seq(2, 12, 2),]
Rdiff_spPEL <- matrix(NA, nrow = 15, ncol = 7)
rownames(Rdiff_spPEL) <- rownames(Rdiff_spPEC)
colnames(Rdiff_spPEL) <- colnames(parameters)
Rdiff_spPEL[1,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[2,])
Rdiff_spPEL[2,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[3,])
Rdiff_spPEL[3,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[4,])
Rdiff_spPEL[4,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[5,])
Rdiff_spPEL[5,] <- mapply(Rdiff, parameters_PEL[1,], parameters_PEL[6,])
Rdiff_spPEL[6,] <- mapply(Rdiff, parameters_PEL[2,], parameters_PEL[3,])
Rdiff_spPEL[7,] <- mapply(Rdiff, parameters_PEL[2,], parameters_PEL[4,])
Rdiff_spPEL[8,] <- mapply(Rdiff, parameters_PEL[2,], parameters_PEL[5,])
Rdiff_spPEL[9,] <- mapply(Rdiff, parameters_PEL[2,], parameters_PEL[6,])
Rdiff_spPEL[10,] <- mapply(Rdiff, parameters_PEL[3,], parameters_PEL[4,])
Rdiff_spPEL[11,] <- mapply(Rdiff, parameters_PEL[3,], parameters_PEL[5,])
Rdiff_spPEL[12,] <- mapply(Rdiff, parameters_PEL[3,], parameters_PEL[6,])
Rdiff_spPEL[13,] <- mapply(Rdiff, parameters_PEL[4,], parameters_PEL[5,])
Rdiff_spPEL[14,] <- mapply(Rdiff, parameters_PEL[4,], parameters_PEL[6,])
Rdiff_spPEL[15,] <- mapply(Rdiff, parameters_PEL[5,], parameters_PEL[6,])
Rdiff_spPEL_muscular <- Rdiff_spPEL
write.csv(round(Rdiff_spPEL_muscular*100, digits=1), file = "Supplementary Table 5. Percentage of relative differences of parameters among pelvic muscular networks.xls")

# 4.4.3. Relative difference PECA vs. PELA
Rdiff_PECvsPEL <- matrix(NA, nrow = 6, ncol = 7)
rownames(Rdiff_PECvsPEL) <- c("Polypterus", "Latimeria", "Neoceratodus", "Ambystoma", "Salamandra", "Sphenodon")
colnames(Rdiff_PECvsPEL) <- colnames(parameters)
for (i in 1:6){
  Rdiff_PECvsPEL[i,] <- mapply(Rdiff, parameters_PEC[i,], parameters_PEL[i,])
}
Rdiff_PECvsPEL_muscular <- Rdiff_PECvsPEL
write.csv(round(Rdiff_PECvsPEL_muscular*100, digits=1), file = "Supplementary Table 6. Percentage of relative difference between pectoral and pelvic muscular networks.xls")

# 4.4.3.1. Plot PEC-PEL differences
svg(filename=paste("Supplementary Figure 2. Relative differences between pectoral and pelvic musculature.svg"), width=7, height=5)
dat <- Rdiff_PECvsPEL_muscular[,-8:-9]*100
matplot(dat, type = c("b"), pch = 1, col = 1:7, xaxt = "n", yaxt = "n", ylab = "PECA vs. PELA Relative Difference (%)") #plot
legend("topright", legend = par_names, col=1:7, pch=1) # optional legend
axis(1, at = 1:6, labels = rownames(dat), cex.axis = 0.9)
axis(2, cex.axis=0.9, las = 1)
dev.off()

# 4.5. Ancestral state reconstructions
# 4.5.1. Load and set tree
tree <- read.tree(file = "fin_limb_tree.txt")
plotname <- c("Number of nodes (N)", "Number of connections (K)", "Density of connections (D)", "Clustering coefficient (C)", "Shortest path length (L)", "Heterogeneity (H)", "Parcellation (P)")
genera <- c("Polypterus", "Latimeria", "Neoceratodus", "Ambystoma", "Salamandra", "Sphenodon")

# 4.5.2. Create phylomorphospaces
svg(filename="Figure 5. Phylomorphospace muscular networks.svg", width=8.27, height=11.69)
par(mfrow = c(4,2))
for (i in 1:7){
  trait1 <- as.vector(parameters_PEC[,i])
  trait2 <- as.vector(parameters_PEL[,i])
  X <- cbind(trait1, trait2)
  rownames(X) <- genera
  range <- as.numeric(c(trait1,trait2))
  tip.cols <- c("blue","cyan","cyan", "dark green", "dark green", "dark green")
  names(tip.cols)<-tree$tip.label
  cols<-c(tip.cols[tree$tip.label],rep("black",tree$Nnode))
  names(cols)<-1:(length(tree$tip)+tree$Nnode)
  par(pty="s")
  phylomorphospace(tree, X, label = "horizontal",
                   xlim = c(min(range),max(range)),
                   ylim = c(min(range),max(range)),
                   xlab = "Pectoral appendage",
                   ylab = "Pelvic appendage",
                   control=list(col.node=cols), lwd=2, ftype = "i")
  abline(a = 0, b = 1, col = "red", lty = "dashed", lwd=0.75)
}
dev.off()

# 4.5.3. Reconstruction values and 95%CI
rec_anc_PEC_muscular <- matrix(0, nrow = 5, ncol = 7)
rownames(rec_anc_PEC_muscular) <- c("Eutelostomi", "Sarcopterygii", "Riphidistia", "Tetrapoda", "Caudata")
colnames(rec_anc_PEC_muscular) <- colnames(parameters)
rec_lower95CI_PEC_muscular <- rec_upper95CI_PEC_muscular <- rec_anc_PEC_muscular
rec_anc_PEL_muscular <- rec_lower95CI_PEL_muscular <- rec_upper95CI_PEL_muscular <- rec_anc_PEC_muscular
for (i in 1:7){
  trait <- as.vector(parameters_PEC[,i]) # for pectoral appendages
  names(trait) <- genera
  rec <- fastAnc(tree,trait, CI = TRUE, vars = FALSE)
  rec_anc_PEC_muscular[,i] <- round(as.numeric(rec$ace), digits = 3)
  rec_lower95CI_PEC_muscular[,i] <-  round(as.numeric(rec$CI95[,1]), digits = 3)
  rec_upper95CI_PEC_muscular[,i] <-  round(as.numeric(rec$CI95[,2]), digits = 3)
  trait <- as.vector(parameters_PEL[,i]) # for pelvic appendages
  names(trait) <- genera
  rec <- fastAnc(tree,trait, CI = TRUE, vars = FALSE)
  rec_anc_PEL_muscular[,i] <- round(as.numeric(rec$ace), digits = 3)
  rec_lower95CI_PEL_muscular[,i] <-  round(as.numeric(rec$CI95[,1]), digits = 3)
  rec_upper95CI_PEL_muscular[,i] <-  round(as.numeric(rec$CI95[,2]), digits = 3)
}
m <- cbind(rec_anc_PEC_muscular, rec_lower95CI_PEC_muscular, rec_upper95CI_PEC_muscular) # combine
ACE_PEC_muscular <- m[, c(matrix(1:ncol(m), nrow = 3, byrow = T))] # then reorder
colnames(ACE_PEC_muscular) <- c("ACE N","Lower 95%CI N", "Upper 95%CI N", "ACE K","Lower 95%CI K", "Upper 95%CI K", "ACE D","Lower 95%CI D", "Upper 95%CI D", "ACE C","Lower 95%CI C", "Upper 95%CI C", "ACE L","Lower 95%CI L", "Upper 95%CI L", "ACE H","Lower 95%CI H", "Upper 95%CI H", "ACE P","Lower 95%CI P", "Upper 95%CI P")
write.csv(ACE_PEC_muscular, file = "Supplementary Table 34. Ancestral state reconstruction of pectoral muscular network parameters (95% CIs).xls")
m <- cbind(rec_anc_PEL_muscular, rec_lower95CI_PEL_muscular, rec_upper95CI_PEL_muscular) # combine
ACE_PEL_muscular <- m[, c(matrix(1:ncol(m), nrow = 3, byrow = T))] # then reorder
colnames(ACE_PEL_muscular) <- colnames(ACE_PEC_muscular)
write.csv(ACE_PEL_muscular, file = "Supplementary Table 35. Ancestral state reconstruction of pelvic muscular network parameters (95% CIs).xls")

# 4.5.4. Moran's I test of autocorrelation
PECA_par <- data.frame(parameters_muscular[seq(1, 12, 2),]) # check this!! maybe change
PELA_par <- data.frame(parameters_muscular[seq(2, 12, 2),])
w <- 1/cophenetic(tree)
diag(w) <- 0
phyautocor_PECA <- phyautocor_PELA <- matrix(NA, nrow = 7, ncol = 3)
colnames(phyautocor_PECA) <- colnames(phyautocor_PELA) <- c("Moran's I", "Zi-score", "p-value")
rownames(phyautocor_PECA) <- rownames(phyautocor_PELA) <- par_names
set.seed(73)
for (i in 1:7){
  patest <- Moran.I(PECA_par[,i], w)
  phyautocor_PECA[i,] <- c(patest$observed, (patest$observed-patest$expected)/patest$sd, patest$p.value)
  patest <- Moran.I(PELA_par[,i], w)
  phyautocor_PELA[i,] <- c(patest$observed, (patest$observed-patest$expected)/patest$sd, patest$p.value)  
}
phyautocor_muscular <- rbind(phyautocor_PECA, phyautocor_PELA) # combine
rownames(phyautocor_muscular) <- c("N pectoral", "K pectoral", "D pectoral", "C pectoral", "L pectoral", "H pectoral", "P pectoral",
                                   "N pelvic", "K pelvic", "D pelvic", "C pelvic", "L pelvic", "H pelvic", "P pelvic")
write.csv(phyautocor_muscular, file = "Supplementary Table 36. Moran's I test of autocorrelation on muscular networks parameters.xls")

# 4.5.5. Regression through the origin of phylogenetic independent contrasts for pectoral-pelvic networks
regOrigin <- matrix(NA, ncol = 4, nrow = 7)
rownames(regOrigin) <- par_names
colnames(regOrigin) <- c("Adjusted r2", "Residual std error", "F-statistic", "p-value")
set.seed(73)
for (i in 1:7){
  reg0 <- lmorigin(pic(PECA_par[,i], tree) ~ pic(PELA_par[,i], tree), silent = T) # regression trought the origin (-1); coefficinet is the slope or how many times y is higher than x
  reg0sum <- summary(reg0$reg)
  regOrigin[i,1] <- reg0sum$adj.r.squared # r2
  regOrigin[i,2] <- reg0sum$sigma # error
  regOrigin[i,3] <- reg0sum$fstatistic[1] # F
  regOrigin[i,4] <- reg0$p.perm.F# pvalue
}
regOrigin_muscular <- regOrigin
write.csv(regOrigin_muscular, file = "Supplementary Table 37. Regression through the origin of phylogenetic independent contrasts for pectoral-pelvic muscular networks.
.xls")
